@@ -6,7 +6,7 @@ use utf8;
 package Marlin;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002002';
+our $VERSION   = '0.002003';
 
 use constant _ATTRS => qw( this parents roles attributes strict constructor modifiers );
 use Exporter::Tiny qw( mkopt _croak );
@@ -19,7 +19,7 @@ use List::Util qw(any);
 
 BEGIN {
 	if ( $] < 5.010 ) {
-		require mro::compat;
+		require MRO::Compat;
 	}
 };
 
